use Apache::Upload::Slurp;

use Test::More tests => 1;
BEGIN { use_ok('Apache::Upload::Slurp') }


#my $obj = new Apache::Upload::Slurp();
#isa_ok( $obj,'Apache::Upload::Slurp', 'testing object ISA');
